@@ -451,4 +451,123 @@ class TestLoginPay(HttpRunner):
                 .assert_equal("body.success", "true")
         ),
     ]
-"""
\ No newline at end of file
+"""
+
+Login_content = """from tep.client import BaseRequest
+
+
+class Login(BaseRequest):
+
+    def post(self):
+        response = self.request(
+            "post",
+            url=self.case_vars.get("domain") + "/login",
+            headers={"Content-Type": "application/json"},
+            json={
+                "username": "dongfanger",
+                "password": "123456",
+            }
+        )
+        assert response.status_code < 400
+        self.case_vars.put("token", response.jmespath("token"))
+"""
+
+SearchSku_content = """from tep.client import BaseRequest
+
+
+class SearchSku(BaseRequest):
+
+    def get(self):
+        response = self.request(
+            "get",
+            url=self.case_vars.get("domain") + "/searchSku",
+            headers={"token": self.case_vars.get("token")},
+            params={"skuName": "电子书"}
+        )
+        self.case_vars.put("skuId", response.jmespath("skuId"))
+        self.case_vars.put("skuPrice", response.jmespath("price"))
+        assert response.status_code < 400
+"""
+
+AddCart_content = """from tep.client import BaseRequest
+
+
+class AddCart(BaseRequest):
+
+    def post(self):
+        response = self.request(
+            "post",
+            url=self.case_vars.get("domain") + "/addCart",
+            headers={"token": self.case_vars.get("token")},
+            json={"skuId": self.case_vars.get("skuId"), "skuNum": self.case_vars.get("skuNum")}
+        )
+        self.case_vars.put("totalPrice", response.jmespath("totalPrice"))
+        assert response.status_code < 400
+"""
+
+Order_content = """from tep.client import BaseRequest
+
+
+class Order(BaseRequest):
+
+    def post(self):
+        response = self.request(
+            "post",
+            url=self.case_vars.get("domain") + "/order",
+            headers={"token": self.case_vars.get("token")},
+            json={"skuId": self.case_vars.get("skuId"), "price": self.case_vars.get("skuPrice"),
+                  "skuNum": self.case_vars.get("skuNum"), "totalPrice": self.case_vars.get("totalPrice")}
+        )
+        self.case_vars.put("orderId", response.jmespath("orderId"))
+        assert response.status_code < 400
+"""
+
+Pay_content = """from tep.client import BaseRequest
+
+
+class Pay(BaseRequest):
+
+    def post(self):
+        response = self.request(
+            "post",
+            url=self.case_vars.get("domain") + "/pay",
+            headers={"token": self.case_vars.get("token")},
+            json={"orderId": self.case_vars.get("orderId"), "payAmount": "6.9"}
+        )
+        assert response.status_code < 400
+        assert response.jmespath("success") == "true"
+"""
+
+test_login_pay_mvc_content = """import allure
+from tep.fixture import TepVars
+
+from services.AddCart import AddCart
+from services.Login import Login
+from services.Order import Order
+from services.Pay import Pay
+from services.SearchSku import SearchSku
+
+\"\"\"
+测试登录到下单流程，需要先运行utils / flask_mock_api.py
+\"\"\"
+
+
+class Test:
+    case_vars = TepVars()
+    case_vars.vars_ = {
+        "domain": "http://127.0.0.1:5000",
+        "skuNum": "3"
+    }
+
+    def test(self):
+        # 登录
+        Login(Test).post()
+        # 搜索商品
+        SearchSku(Test).get()
+        # 添加购物车
+        AddCart(Test).post()
+        # 下单
+        Order(Test).post()
+        # 支付
+        Pay(Test).post()
+"""
